<!DOCTYPE html
    PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="en">
  <head>
    <title>{{ title }}</title>
  </head>
  <body>

{%- macro greeting(name) %}
      <p>hello {{ name }}</p>
{%- endmacro %}

    <div id="header">
      <h1>{{ title }}</h1>
    </div>

{%- block body %}{%- endblock %}

    <div id="footer">
    </div>

  </body>
</html>
