{% extends "base.html" %}
{% block body %}
    {{ greeting(user) }}
    {{ greeting('me') }}
    {{ greeting('world') }}

    <h2>Loop</h2>
    {%- if list_items %}
      <ul>
        {%- for list_item in list_items %}
	<li {{ "class='last'" if loop.last else ""}}>{{ list_item }}</li>
        {%- endfor %}
      </ul>
    {%- endif %}
{% endblock body %}
