<!DOCTYPE html
    PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="en">

  {% block body %}
    <div id="header">
      <h1>{{ title|escape }}</h1>
    </div>
    {{ block.super }}
    <div id="footer"></div>
  {% endblock %}

</html>
